@@ -3,8 +3,6 @@ package Math::Vec2;
 use strict;
 use warnings;
 
-use Carp;
-
 #use Exporter;
 
 use overload
@@ -27,7 +25,7 @@ use overload
   '""'   => \&toString,
   ;
 
-our $VERSION = '0.01';
+our $VERSION = '0.1';
 
 =head1 NAME
 
@@ -39,8 +37,9 @@ Math::Vec2 - Perl class to represent 2d vectors
 
 =head1 SEE ALSO
 
+L<Math>
+
 L<Math::Color>, L<Math::Image>, L<Math::Vec2>, L<Math::Vec3>, L<Math::Rotation>
-L<Math::Quaternion>
 
 =head1 SYNOPSIS
 	
@@ -80,12 +79,12 @@ sub new {
 		} elsif ( $ref->isa("Math::Vec2") ) {
 			$this->setValue(@$arg1);
 		} else {
-			croak("Don't understand arguments passed to new()");
+			warn("Don't understand arguments passed to new()");
 		}
 	} elsif ( 2 == @_ ) {    # x,y
 		$this->setValue(@_);
 	} else {
-		croak("Don't understand arguments passed to new()");
+		warn("Don't understand arguments passed to new()");
 	}
 
 	return $this;
@@ -149,7 +148,7 @@ Returns the @value of the vector
 
 =cut
 
-sub getValue { @{ $_[0] } }
+sub getValue { map { $_ || 0 } @{ $_[0] } }
 
 =head2 x
 
@@ -402,11 +401,7 @@ sub toString {
 
 =head1 SEE ALSO
 
-L<perlfunc>
-
-L<POSIX>
-
-L<Math::Complex>, L<Math::Trig>, L<Math::Quaternion>
+L<Math>
 
 L<Math::Color>, L<Math::Image>, L<Math::Vec2>, L<Math::Vec3>, L<Math::Rotation>
 
@@ -418,7 +413,7 @@ please drop the author a note.
 
 =head1 ARRANGED BY
 
-	Holger Seelig  E<holger.seelig@yahoo.de>
+Holger Seelig  holger.seelig@yahoo.de
 
 =head1 COPYRIGHT
 
